﻿using AutoMapper;

using Model;
using Model.Dto;
using Model.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BlankApp1.Common.AutoMapper
{
    public class AutoMapProfile : Profile
    {
        public AutoMapProfile()
        {
            CreateMap<Menu, MenuDto>().ReverseMap(); 
            CreateMap<OptionConfig, OptionConfigDto>().ReverseMap(); 
            CreateMap<bas_plc_item_config, BasPlcItemConfigDto>()
                .ForMember(dest => dest.Id, opt => opt.MapFrom(src => src.id))
                .ForMember(dest => dest.PlcCode, opt => opt.MapFrom(src => src.plc_code))
                .ForMember(dest => dest.PlcItem, opt => opt.MapFrom(src => src.plc_item))
                .ForMember(dest => dest.PlcAddress, opt => opt.MapFrom(src => src.plc_address))
                .ForMember(dest => dest.PlcAddType, opt => opt.MapFrom(src => src.plc_addType))
                .ForMember(dest => dest.PlcValue, opt => opt.MapFrom(src => src.plc_value))
                .ForMember(dest => dest.Remark, opt => opt.MapFrom(src => src.remark)).ReverseMap(); 

            CreateMap<bas_plc_test_scheme, BasicPlcTestSchemeDto>()
                .ForMember(dest => dest.SchemeId, opt => opt.MapFrom(src => src.scheme_id))
                .ForMember(dest => dest.SchemeName, opt => opt.MapFrom(src => src.scheme_name))
                .ForMember(dest => dest.DeviceName, opt => opt.MapFrom(src => src.device_name))
                .ForMember(dest => dest.CreateBy, opt => opt.MapFrom(src => src.create_by))
                .ForMember(dest => dest.CreateTime, opt => opt.MapFrom(src => src.create_time))
                .ForMember(dest => dest.UpdateTime, opt => opt.MapFrom(src => src.update_time))
                .ForMember(dest => dest.UpdateBy, opt => opt.MapFrom(src => src.update_by))
                .ForMember(dest => dest.Remark, opt => opt.MapFrom(src => src.remark)).ReverseMap();

            CreateMap<bas_plc_test_scheme_dtl, BasicPlcTestSchemeDtlDto>()
                .ForMember(dest => dest.SchemeDtlId, opt => opt.MapFrom(src => src.scheme_dtl_id))
                .ForMember(dest => dest.SchemeId, opt => opt.MapFrom(src => src.scheme_id))
                .ForMember(dest => dest.ItemName, opt => opt.MapFrom(src => src.item_name))
                 .ForMember(dest => dest.ItemType, opt => opt.MapFrom(src => ItemTypeToStr(src.item_type)))
                  .ForMember(dest => dest.Precondition, opt => opt.MapFrom(src => src.precondition))
                   .ForMember(dest => dest.PreconditionDescribe, opt => opt.MapFrom(src => src.precondition_describe))
                    .ForMember(dest => dest.Action, opt => opt.MapFrom(src => src.action))
                     .ForMember(dest => dest.ActionDescribe, opt => opt.MapFrom(src => src.action_describe))
                      .ForMember(dest => dest.JudgementResult, opt => opt.MapFrom(src => src.judgement_result))
                     .ForMember(dest => dest.JudgementResultDescribe, opt => opt.MapFrom(src => src.judgement_result_describe))
                .ForMember(dest => dest.CreateBy, opt => opt.MapFrom(src => src.create_by))
                .ForMember(dest => dest.CreateTime, opt => opt.MapFrom(src => src.create_time))
                .ForMember(dest => dest.UpdateTime, opt => opt.MapFrom(src => src.update_time))
                .ForMember(dest => dest.UpdateBy, opt => opt.MapFrom(src => src.update_by))
                .ForMember(dest => dest.Remark, opt => opt.MapFrom(src => src.remark)).ReverseMap();

            CreateMap<biz_test_record, BizTestRecordDto>()
                 .ForMember(dest => dest.RecordId, opt => opt.MapFrom(src => src.record_id))
                  .ForMember(dest => dest.RecordName, opt => opt.MapFrom(src => src.record_name))
                   .ForMember(dest => dest.SchemeName, opt => opt.MapFrom(src => src.scheme_name))
                    .ForMember(dest => dest.Tester, opt => opt.MapFrom(src => src.tester))
                     .ForMember(dest => dest.StartTestTime, opt => opt.MapFrom(src => src.start_test_time))
                      .ForMember(dest => dest.FinishTestTime, opt => opt.MapFrom(src => src.finish_test_time))
                       .ForMember(dest => dest.Status, opt => opt.MapFrom(src => src.status))
                        .ForMember(dest => dest.CreateBy, opt => opt.MapFrom(src => src.create_by))
                         .ForMember(dest => dest.CreateTime, opt => opt.MapFrom(src => src.create_time))
                          .ForMember(dest => dest.UpdateTime, opt => opt.MapFrom(src => src.update_time))
                                .ForMember(dest => dest.UpdateBy, opt => opt.MapFrom(src => src.update_by))
                         .ForMember(dest => dest.Remark, opt => opt.MapFrom(src => src.remark)).ReverseMap();


            CreateMap<biz_test_record_dtl, BizTestRecordDtlDto>()
                .ForMember(dest => dest.RecordDtlId, opt => opt.MapFrom(src => src.record_dtl_id))
                 .ForMember(dest => dest.RecordId, opt => opt.MapFrom(src => src.record_id))
                   .ForMember(dest => dest.SchemeDtlId, opt => opt.MapFrom(src => src.scheme_dtl_id))
                     .ForMember(dest => dest.StartTestTime, opt => opt.MapFrom(src => src.start_test_time))
                      .ForMember(dest => dest.FinishTestTime, opt => opt.MapFrom(src => src.finish_test_time))
                       .ForMember(dest => dest.PreconditionFinal, opt => opt.MapFrom(src => src.precondition_final))
                        .ForMember(dest => dest.ActionFinal, opt => opt.MapFrom(src => src.action_final))
                         .ForMember(dest => dest.JudgementResultFinal, opt => opt.MapFrom(src => src.judgement_result_final))

                      .ForMember(dest => dest.TestMode, opt => opt.MapFrom(src => src.test_mode))
                       .ForMember(dest => dest.TestResult, opt => opt.MapFrom(src => src.test_result))
                       .ForMember(dest => dest.Status, opt => opt.MapFrom(src => src.status))
                        .ForMember(dest => dest.CreateBy, opt => opt.MapFrom(src => src.create_by))
                         .ForMember(dest => dest.CreateTime, opt => opt.MapFrom(src => src.create_time))
                          .ForMember(dest => dest.UpdateTime, opt => opt.MapFrom(src => src.update_time))
                             .ForMember(dest => dest.UpdateBy, opt => opt.MapFrom(src => src.update_by))
                         .ForMember(dest => dest.Remark, opt => opt.MapFrom(src => src.remark)).ReverseMap();

        }

        private string ItemTypeToStr(int? type)
        {
            string itemStr = string.Empty; ;
            switch(type) 
            {
                case 0:
                    itemStr = "前置项";
                    break;
                case 1:
                    itemStr = "PLC点位测试项";
                    break;
                case 2:
                    itemStr = "Robot动作测试";
                    break;
            }
            return itemStr;
        }

        private int StrToItemType(string  typeStr)
        {
            int itemInt = 0;
            switch (typeStr)
            {
                case "前置项":
                    itemInt = 0;
                    break;
                case "PLC点位测试项":
                    itemInt = 1;
                    break;
                case "Robot动作测试":
                    itemInt =2;
                    break;
            }
            return itemInt;
        }


    }
}
