﻿using AutoMapper;
using BizService;
using Model.Dto;
using Model.Entities;
using PLCTool.Common;
using Prism.Commands;
using Prism.Mvvm;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.MonitorManageViewModel
{
    public  class PLCWriteViewModel:BindableBase
    {
        private readonly IBasicPlcItemConfigService _iBasPlcItemConfigService;

        private readonly IMapper _mapper;
        private List<BasPlcItemConfigDto> plcConfigs = new List<BasPlcItemConfigDto>();
        public PLCWriteViewModel(IBasicPlcItemConfigService iBasPlcItemConfigService, IMapper mapper)
        {

            _iBasPlcItemConfigService = iBasPlcItemConfigService;
            _mapper = mapper;
            WriteCommand = new DelegateCommand<object>(WriteToPlc);
            GetPLCConfig();
        }


        #region 私有方法

        private void WriteToPlc(object obj)
        {//没有连接 plc，直接退出
            if (!PLCCom.GetInstance().IsConnectPLC())
            {
                MessageBox.Show("PLC未连接！", "提示", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;
            }
          
            long id = Convert.ToInt64(obj);
            var findPlcItem= PLCItemList.FirstOrDefault(l => l.Id == id);
            if(findPlcItem!=null)
            {
                string plcAddr = findPlcItem.PlcAddress;
                string plcAddType = findPlcItem.PlcAddType;
                string plcValue = findPlcItem.PlcValue;
                if (string.IsNullOrEmpty(plcValue))
                {
                    MessageBox.Show("请填写数据！", "提示", MessageBoxButton.OK, MessageBoxImage.Warning);
                    return;
                }
                switch (plcAddType)
                {
                    case "bool":
                        bool isResult = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.Bit, plcValue);
                        if(isResult)
                        {
                            MessageBox.Show("写入成功！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                        }
                        break;
                    case "word":
                        bool isResult2 = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.Word, plcValue);
                        if (isResult2)
                        {
                            MessageBox.Show("写入成功！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                        }
                        break;
                    case "dword":
                        bool isResult3 = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.DWord, plcValue);
                        if (isResult3)
                        {
                            MessageBox.Show("写入成功！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                        }
                        break;
                    case "real":
                       
                        bool isResult4 = PLCCom.GetInstance().WritePlcObject(plcAddr, VarType.Real, plcValue);
                        if (isResult4)
                        {
                            MessageBox.Show("写入成功！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                        }
                        break;
                }

            }
        
        }
        /// <summary>
        /// 获取PLC配置
        /// </summary>
        private void GetPLCConfig()
        {
            var plclist = _iBasPlcItemConfigService.QueryList();
            plcConfigs = _mapper.Map<List<bas_plc_item_config>, List<BasPlcItemConfigDto>>(plclist);
            foreach (var plc in plcConfigs)
            {
                PLCItemList.Add(plc);
            }
        }

    
        #endregion
        #region 数据绑定
        private ObservableCollection<BasPlcItemConfigDto> plcItemList = new ObservableCollection<BasPlcItemConfigDto>();
        public ObservableCollection<BasPlcItemConfigDto> PLCItemList
        {
            get { return plcItemList; }
            set { plcItemList = value; RaisePropertyChanged(); }
        }

    
        #endregion

        #region 命令绑定

        public DelegateCommand<object> WriteCommand { set; get; }
        #endregion
    }
}

